/*
 * =====================================================================================
 * 
 *    Corporation:  Shenzhen Maibu Technology Co., Ltd. All Rights Reserved.
 *       Filename:  app_run_helper.c
 *         Author:  gliu , gliu@maibu.cc
 *        Created:  2015年10月13日 09时58分07秒
 * 
 *    Description:  跑步助手
 *
 * =====================================================================================
 *
 * =====================================================================================
 * 
 *   MODIFICATION HISTORY :
 *    
 *		     DATE :
 *		     DESC :
 * =====================================================================================
 */	
#include <stdlib.h>
#include <stdio.h>
#include <string.h>


#ifdef LINUX
#include <unistd.h>
#include <time.h>
#include <pthread.h>
#include "linux_screen_show.h"
#include "os_store_manage.h"
#include "os_time.h"
#include "os_res_bitmap.h"
#include "os_comm.h"
#include "res_user_bitmap.h"
#include "os_memory_manage.h"
#include "os_motor.h"
#include "os_lights.h"
#include "window_stack.h"
#include "window.h"
#include "screen_show.h"
#include "matrix.h"
#include "plug_status_bar.h"
#include "res_bitmap_base.h"
#include "os_app_manage.h"
#include "os_user_app_id.h"
#include "sports_data_manager.h"
#else

#include "maibu_sdk.h"
#include "maibu_res.h"

#endif



/*首页图层位置*/
#define RUN_HELPER_INTRO_ORIGIN_X			0	
#define RUN_HELPER_INTRO_ORIGIN_Y			0
#define RUN_HELPER_INTRO_SIZE_H				128	
#define RUN_HELPER_INTRO_SIZE_W				128	


/*中间状态栏图层位置*/
#define RUN_HELPER_STATUS_BAR_ORIGIN_X			0
#define RUN_HELPER_STATUS_BAR_ORIGIN_Y			0
#define RUN_HELPER_STATUS_BAR_SIZE_H			12	
#define RUN_HELPER_STATUS_BAR_SIZE_W			104


/*标签图层位置*/
#define RUN_HELPER_LABEL_ORIGIN_X			2
#define RUN_HELPER_LABEL_ORIGIN_Y			29
#define RUN_HELPER_LABEL_SIZE_H				85	
#define RUN_HELPER_LABEL_SIZE_W				19

/*侧边栏背景图层位置*/
#define RUN_HELPER_SIDE_BG_ORIGIN_X			104
#define RUN_HELPER_SIDE_BG_ORIGIN_Y			0
#define RUN_HELPER_SIDE_BG_SIZE_H			128
#define RUN_HELPER_SIDE_BG_SIZE_W			24

/*侧边栏开始暂停图层位置*/
#define RUN_HELPER_SIDE_PLAY_PAUSE_ORIGIN_X			108
#define RUN_HELPER_SIDE_PLAY_PAUSE_ORIGIN_Y			12
#define RUN_HELPER_SIDE_PLAY_PAUSE_SIZE_H			16
#define RUN_HELPER_SIDE_PLAY_PAUSE_SIZE_W			16


/*距离图层*/
#define RUN_HELPER_DISTANCE_ORIGIN_X			21
#define RUN_HELPER_DISTANCE_ORIGIN_Y			19
#define RUN_HELPER_DISTANCE_SIZE_H			30
#define RUN_HELPER_DISTANCE_SIZE_W			82

/*计时图层*/
#define RUN_HELPER_TIME_ORIGIN_X			21
#define RUN_HELPER_TIME_ORIGIN_Y			54
#define RUN_HELPER_TIME_SIZE_H				30	
#define RUN_HELPER_TIME_SIZE_W				82

/*配速图层*/
#define RUN_HELPER_SPEED_ORIGIN_X			21
#define RUN_HELPER_SPEED_ORIGIN_Y			93
#define RUN_HELPER_SPEED_SIZE_H				30
#define RUN_HELPER_SPEED_SIZE_W				82

/*运动结束背景图层*/
#define RUN_HELPER_FINISH_ORIGIN_X			0
#define RUN_HELPER_FINISH_ORIGIN_Y			0
#define RUN_HELPER_FINISH_SIZE_H			128
#define RUN_HELPER_FINISH_SIZE_W			128


/*运动结束总距离图层*/
#define RUN_HELPER_FINISH_DISTANCE_ORIGIN_X			2
#define RUN_HELPER_FINISH_DISTANCE_ORIGIN_Y			68
#define RUN_HELPER_FINISH_DISTANCE_SIZE_H			24
#define RUN_HELPER_FINISH_DISTANCE_SIZE_W			68


/*运动结束热量图层*/
#define RUN_HELPER_FINISH_CALORIE_ORIGIN_X			70
#define RUN_HELPER_FINISH_CALORIE_ORIGIN_Y			68
#define RUN_HELPER_FINISH_CALORIE_SIZE_H			24
#define RUN_HELPER_FINISH_CALORIE_SIZE_W			56


/*运动结束平均配速图层*/
#define RUN_HELPER_FINISH_AVERAGE_SPEED_ORIGIN_X			2
#define RUN_HELPER_FINISH_AVERAGE_SPEED_ORIGIN_Y			110
#define RUN_HELPER_FINISH_AVERAGE_SPEED_SIZE_H			16
#define RUN_HELPER_FINISH_AVERAGE_SPEED_SIZE_W			68


/*运动结束最高配速图层*/
#define RUN_HELPER_FINISH_MAX_SPEED_ORIGIN_X			70
#define RUN_HELPER_FINISH_MAX_SPEED_ORIGIN_Y			110
#define RUN_HELPER_FINISH_MAX_SPEED_SIZE_H			16
#define RUN_HELPER_FINISH_MAX_SPEED_SIZE_W			56


/*实时配速取的是几秒内的距离进行计算*/
#define RUN_HELPER_SECONDS_INTERVAL	10


/*状态*/
#define RUN_HELPER_STATE_INTRO		0
#define RUN_HELPER_STATE_PLAY		1
#define RUN_HELPER_STATE_PAUSE		2
#define RUN_HELPER_STATE_FINISH		3


typedef struct tag_Run
{
	int8_t   state;		//状态，引导状态，计数状态、暂停状态、完成状态
	int8_t 	 flag;		//开启定时器标志
	uint32_t sys_micro;	//现在毫秒数
	int32_t  time;		//跑步计数,单位秒
	int32_t  total_distance;	//总距离，单位10cm
	int32_t  pre_distance;	//前一秒的距离
	int32_t  pre_n_distanc;	//前RUN_HELPER_SECONDS_INTERVAL的距离;
	int32_t  pre_n_total_distance; //前RUN_HELPER_SECONDS_INTERVAL的总距离;
	int16_t  curr_speed;	//实时速度，分钟/公里
	int16_t  max_speed;	//最高速度，分钟/公里
	uint32_t total_calorie;	//卡路里
	uint32_t pre_calorie;	//前一秒的卡路里
}Run;

static Run g_run;


/*窗口ID*/
static int32_t g_run_window_id = -1;

/*状态栏时间图层ID*/
static int8_t g_run_status_bar_layer_id = -1;

/*距离图层ID*/
static int8_t g_run_distance_layer_id = -1;

/*计时图层ID*/
static int8_t g_run_time_layer_id = -1;

/*配速图层ID*/
static int8_t g_run_speed_layer_id = -1;

/*开始暂停图层*/
static int8_t g_run_play_pause_layer_id = -1;


/*定时器ID*/
static int8_t g_run_timer_id = -1;


extern P_Window run_helper_create_init_window();
extern P_Window run_helper_create_finish_window();
extern P_Window run_helper_create_record_window();
extern P_Window run_helper_create_intro_window();
extern void run_helper_timer_callback(date_time_t tick_time, uint32_t millis, void *context);



/*定义后退按键事件*/
static void run_helper_select_back(void *context)
{
	P_Window p_window = (P_Window)context;
	if (NULL != p_window)
	{
		app_window_stack_pop(p_window);
	}
}


/*定义后退按键事件*/
static void run_helper_finish_select_back(void *context)
{
	P_Window p_window = (P_Window)context;
	if (NULL != p_window)
	{
		memset(&g_run, 0, sizeof(Run));
		app_window_stack_pop(p_window);
	}
}


/*定义上按键事件*/
static void run_helper_select_up(void *context)
{
	P_Window p_window = (P_Window)context;
	if (NULL != p_window)
	{
		GBitmap bmp;
		P_Layer p_layer = app_window_get_layer_by_id(p_window, g_run_play_pause_layer_id);
		if (g_run.state == RUN_HELPER_STATE_PLAY)
		{
			res_get_user_bitmap(RES_BITMAP_WATCHAPP_RUN_HELPER_SIDE_PLAY_BMP, &bmp);
			g_run.state = RUN_HELPER_STATE_PAUSE;
			app_service_timer_unsubscribe(g_run_timer_id);
			g_run_timer_id = -1;

		}
		else
		{
			res_get_user_bitmap(RES_BITMAP_WATCHAPP_RUN_HELPER_SIDE_PAUSE_BMP, &bmp);
			g_run.state = RUN_HELPER_STATE_PLAY;
			g_run.flag = 1;
			
			SportData data;
			maibu_get_sport_data(&data, 0);		
			g_run.pre_distance = data.distance;
			g_run.pre_calorie = data.calorie;
			g_run_timer_id = app_service_timer_subscribe(1000, run_helper_timer_callback, (void *)p_window);

		}
		app_layer_set_bitmap_bitmap(p_layer, &bmp);
		app_window_update(p_window);	
	}
}


/*定义下按键事件*/
static void run_helper_select_down(void *context)
{
	P_Window p_window = (P_Window)context;
	if (NULL != p_window)
	{
		if(g_run_timer_id != -1)	
		{
			app_service_timer_unsubscribe(g_run_timer_id);
			g_run_timer_id = -1;
		}
			
		g_run.state = RUN_HELPER_STATE_FINISH;
		P_Window p_new_window = run_helper_create_finish_window();
		g_run_window_id = app_window_stack_replace_window(p_window, p_new_window);	
	}
}



static void run_helper_select_select(void *context)
{

	P_Window p_window = (P_Window)context;
	if (NULL != p_window)
	{
		P_Window p_new_window = run_helper_create_record_window();
		g_run.state = RUN_HELPER_STATE_PLAY;
		g_run.flag = 1;
		SportData data;
		maibu_get_sport_data(&data, 0);		
		g_run.pre_distance = data.distance;
		g_run.pre_calorie = data.calorie;
		g_run_timer_id = app_service_timer_subscribe(1000, run_helper_timer_callback, (void *)p_new_window);
		g_run_window_id = app_window_stack_replace_window(p_window, p_new_window);	
	}
}


static void run_helper_finish_select_select(void *context)
{

	P_Window p_window = (P_Window)context;
	if (NULL != p_window)
	{
		memset(&g_run, 0, sizeof(Run));
		P_Window p_new_window = run_helper_create_intro_window();
		g_run_window_id = app_window_stack_replace_window(p_window, p_new_window);	
	}
}





/*
 *--------------------------------------------------------------------------------------
 *     function:  run_helper_create_record_window
 *    parameter: 
 *       return:
 *  description:  创建记录窗口
 * 	  other:
 *--------------------------------------------------------------------------------------
 */
P_Window run_helper_create_record_window()
{

	P_Window p_window = app_window_create();
	if (NULL == p_window)
	{
		return NULL;
	}

	/*添加状态栏图层*/
	GRect status_bar_frame = {{RUN_HELPER_STATUS_BAR_ORIGIN_X, RUN_HELPER_STATUS_BAR_ORIGIN_Y}, 
				{RUN_HELPER_STATUS_BAR_SIZE_H, RUN_HELPER_STATUS_BAR_SIZE_W}};
	struct date_time datetime;
	app_service_get_datetime(&datetime);
	char buf[6] = "";
	sprintf(buf, "%02d:%02d", datetime.hour, datetime.min);
	LayerText status_bar_text = {buf, status_bar_frame, GAlignCenter, U_ASCII_ARIAL_12};
	P_Layer status_bar_layer = app_layer_create_text(&status_bar_text);
	g_run_status_bar_layer_id = app_window_add_layer(p_window, status_bar_layer);


	/*添加标签*/
	GRect label_frame = {{RUN_HELPER_LABEL_ORIGIN_X, RUN_HELPER_LABEL_ORIGIN_Y}, 
			{ RUN_HELPER_LABEL_SIZE_H, RUN_HELPER_LABEL_SIZE_W}};
	GBitmap label_bitmap;
	res_get_user_bitmap(RES_BITMAP_WATCHAPP_RUN_HELPER_LABEL_BMP, &label_bitmap);
	LayerBitmap label_lb = {label_bitmap, label_frame, GAlignCenter};	
	P_Layer	 label_layer = app_layer_create_bitmap(&label_lb);
	app_window_add_layer(p_window, label_layer);


	/*添加侧边栏图层*/
	GRect side_bg_frame = {{RUN_HELPER_SIDE_BG_ORIGIN_X, RUN_HELPER_SIDE_BG_ORIGIN_Y}, 
			{ RUN_HELPER_SIDE_BG_SIZE_H, RUN_HELPER_SIDE_BG_SIZE_W}};
	GBitmap side_bg_bitmap;
	res_get_user_bitmap(RES_BITMAP_WATCHAPP_RUN_HELPER_SIDE_BG_BMP, &side_bg_bitmap);
	LayerBitmap side_bg_lb = {side_bg_bitmap, side_bg_frame, GAlignCenter};	
	P_Layer	 side_bg_layer = app_layer_create_bitmap(&side_bg_lb);
	app_window_add_layer(p_window, side_bg_layer);

	/*添加开始或暂停图层*/
	GRect side_play_frame = {{RUN_HELPER_SIDE_PLAY_PAUSE_ORIGIN_X, RUN_HELPER_SIDE_PLAY_PAUSE_ORIGIN_Y}, 
			{ RUN_HELPER_SIDE_PLAY_PAUSE_SIZE_H, RUN_HELPER_SIDE_PLAY_PAUSE_SIZE_W}};
	GBitmap side_play_bitmap;
	if ((g_run.time == 0) || (g_run.state == RUN_HELPER_STATE_PLAY))
	{
		res_get_user_bitmap(RES_BITMAP_WATCHAPP_RUN_HELPER_SIDE_PAUSE_BMP, &side_play_bitmap);
	}
	else 
	{
		res_get_user_bitmap(RES_BITMAP_WATCHAPP_RUN_HELPER_SIDE_PLAY_BMP, &side_play_bitmap);
	}
	LayerBitmap side_play_lb = {side_play_bitmap, side_play_frame, GAlignCenter};	
	P_Layer	 side_play_pause_layer = app_layer_create_bitmap(&side_play_lb);
	g_run_play_pause_layer_id = app_window_add_layer(p_window, side_play_pause_layer);


	/*添加距离文本图层*/
	GRect distance_frame = {{RUN_HELPER_DISTANCE_ORIGIN_X, RUN_HELPER_DISTANCE_ORIGIN_Y}, 
				{RUN_HELPER_DISTANCE_SIZE_H, RUN_HELPER_DISTANCE_SIZE_W}};
	sprintf(buf, "%01d.%02d", g_run.total_distance/100000, (g_run.total_distance/1000)%100);
	LayerText distance_text = {buf, distance_frame, GAlignRight, U_ASCII_ARIAL_30};
	P_Layer distance_layer = app_layer_create_text(&distance_text);
	g_run_distance_layer_id = app_window_add_layer(p_window, distance_layer);


	/*添加计时文本图层*/
	GRect time_frame = {{RUN_HELPER_TIME_ORIGIN_X, RUN_HELPER_TIME_ORIGIN_Y}, 
				{RUN_HELPER_TIME_SIZE_H, RUN_HELPER_TIME_SIZE_W}};
	if ((g_run.time/1000) >= 3600)
	{
		sprintf(buf, "%01d:%02d",  g_run.time/3600000, (g_run.time/60000)%60);
	}
	else
	{
		sprintf(buf, "%01d:%02d",  g_run.time/60000, (g_run.time/1000)%60);
	}
	LayerText time_text = {buf, time_frame, GAlignRight, U_ASCII_ARIAL_30};
	P_Layer time_layer = app_layer_create_text(&time_text);
	g_run_time_layer_id = app_window_add_layer(p_window, time_layer);

	
	/*添加配速文本图层*/
	GRect speed_frame = {{RUN_HELPER_SPEED_ORIGIN_X, RUN_HELPER_SPEED_ORIGIN_Y}, 
				{RUN_HELPER_SPEED_SIZE_H, RUN_HELPER_SPEED_SIZE_W}};
//	int32_t hour_speed = g_run.curr_speed * 60;
//	sprintf(buf, "%01d:%02d", hour_speed/100000, (hour_speed/1000)%100);

	int32_t tmp = g_run.curr_speed == 0 ? 1 : g_run.curr_speed;
	int32_t hour_speed = (100000/tmp);
	if (hour_speed >= 6000)
	{
		strcpy(buf, "0:00");
	}
	else
	{
		sprintf(buf, "%01d:%02d", hour_speed/60, hour_speed%60);
	}

	LayerText speed_text = {buf, speed_frame, GAlignRight, U_ASCII_ARIAL_30};
	P_Layer speed_layer = app_layer_create_text(&speed_text);
	g_run_speed_layer_id = app_window_add_layer(p_window, speed_layer);


	/*这里先注册按键回调, 在回调中再具体处理回调怎么相应*/
	app_window_click_subscribe(p_window, ButtonIdBack, run_helper_select_back);
	app_window_click_subscribe(p_window, ButtonIdUp, run_helper_select_up);
	app_window_click_subscribe(p_window, ButtonIdDown, run_helper_select_down);

	return p_window;
}




/*
 *--------------------------------------------------------------------------------------
 *     function:  run_helper_create_intro_window
 *    parameter: 
 *       return:
 *  description:  创建引导窗口
 * 	  other:
 *--------------------------------------------------------------------------------------
 */
P_Window run_helper_create_intro_window()
{
	P_Window p_window = app_window_create();
	if (NULL == p_window)
	{
		return NULL;
	}

	/*添加引导图层*/
	GRect intro_frame = {{RUN_HELPER_INTRO_ORIGIN_X, RUN_HELPER_INTRO_ORIGIN_Y}, 
				{RUN_HELPER_INTRO_SIZE_H, RUN_HELPER_INTRO_SIZE_W}};
	GBitmap bitmap;
	res_get_user_bitmap(RES_BITMAP_WATCHAPP_RUN_HELPER_INTRO_BMP, &bitmap);
	LayerBitmap lb = {bitmap, intro_frame, GAlignCenter};	
	P_Layer	 layer = app_layer_create_bitmap(&lb);
	app_window_add_layer(p_window, layer);

	app_window_click_subscribe(p_window, ButtonIdSelect, run_helper_select_select);
	app_window_click_subscribe(p_window, ButtonIdBack, run_helper_select_back);
	return p_window;
}



/*
 *--------------------------------------------------------------------------------------
 *     function:  run_helper_create_finish_window
 *    parameter: 
 *       return:
 *  description:  创建完成窗口
 * 	  other:
 *--------------------------------------------------------------------------------------
 */
P_Window run_helper_create_finish_window()
{

	P_Window p_window = app_window_create();
	if (NULL == p_window)
	{
		return NULL;
	}

	/*添加状态栏, 显示时间*/
	app_plug_status_bar_create(p_window, NULL, NULL, NULL);
	app_plug_status_bar_add_time(p_window);


	/*添加背景图层*/
	GRect bg_frame = {{RUN_HELPER_FINISH_ORIGIN_X, RUN_HELPER_FINISH_ORIGIN_Y}, 
				{RUN_HELPER_FINISH_SIZE_H, RUN_HELPER_FINISH_SIZE_W}};
	GBitmap bg_bitmap;
	res_get_user_bitmap(RES_BITMAP_WATCHAPP_RUN_HELPER_FINISH_BMP, &bg_bitmap);
	LayerBitmap bg_lb = {bg_bitmap, bg_frame, GAlignCenter};	
	P_Layer	 bg_layer = app_layer_create_bitmap(&bg_lb);
	app_window_add_layer(p_window, bg_layer);

	/*添加总距离*/
	GRect distance_frame = {{RUN_HELPER_FINISH_DISTANCE_ORIGIN_X, RUN_HELPER_FINISH_DISTANCE_ORIGIN_Y}, 
				{RUN_HELPER_FINISH_DISTANCE_SIZE_H, RUN_HELPER_FINISH_DISTANCE_SIZE_W}};
	char buf[8] = "";
	sprintf(buf, "%01d.%02d", g_run.total_distance/100000, (g_run.total_distance/1000)%100);
	LayerText distance_text = {buf, distance_frame, GAlignLeft, U_ASCII_ARIAL_24};
	P_Layer distance_layer = app_layer_create_text(&distance_text);
	app_window_add_layer(p_window, distance_layer);


	/*添加热量消耗*/
	GRect calorie_frame = {{RUN_HELPER_FINISH_CALORIE_ORIGIN_X, RUN_HELPER_FINISH_CALORIE_ORIGIN_Y}, 
				{RUN_HELPER_FINISH_CALORIE_SIZE_H, RUN_HELPER_FINISH_CALORIE_SIZE_W}};
	sprintf(buf, "%d", g_run.total_calorie);
	LayerText calorie_text = {buf, calorie_frame, GAlignLeft, U_ASCII_ARIAL_24};
	P_Layer calorie_layer = app_layer_create_text(&calorie_text);
	app_window_add_layer(p_window, calorie_layer);


	/*添加平均配速消耗*/
	GRect average_speed_frame = {{RUN_HELPER_FINISH_AVERAGE_SPEED_ORIGIN_X, RUN_HELPER_FINISH_AVERAGE_SPEED_ORIGIN_Y}, 
				{RUN_HELPER_FINISH_AVERAGE_SPEED_SIZE_H, RUN_HELPER_FINISH_AVERAGE_SPEED_SIZE_W}};

//	int32_t tmp = 	g_run.total_distance*60/(g_run.time/1000);
//	sprintf(buf, "%01d:%02d", tmp/100000, (tmp/1000)%100);

	int32_t tmp = g_run.time/1000;
	tmp = (tmp == 0) ? 1 : tmp;	
	int32_t speed = g_run.total_distance / tmp;
	speed = (speed == 0) ?  1 : speed;			
	speed = (100000/speed);
	if (speed >= 6000)
	{
		strcpy(buf, "0:00");
	}
	else
	{
		sprintf(buf, "%01d:%02d", speed/60, speed%60);
	}


	LayerText average_speed_text = {buf, average_speed_frame, GAlignLeft, U_ASCII_ARIAL_16};
	P_Layer average_speed_layer = app_layer_create_text(&average_speed_text);
	app_window_add_layer(p_window, average_speed_layer);
	

	/*添加最高配速消耗*/
	GRect max_speed_frame = {{RUN_HELPER_FINISH_MAX_SPEED_ORIGIN_X, RUN_HELPER_FINISH_MAX_SPEED_ORIGIN_Y}, 
				{RUN_HELPER_FINISH_MAX_SPEED_SIZE_H, RUN_HELPER_FINISH_MAX_SPEED_SIZE_W}};
//	tmp = 	g_run.max_speed*60;
//	sprintf(buf, "%01d:%02d", tmp/100000, (tmp/1000)%100);

	tmp = g_run.max_speed == 0 ? 1 : g_run.max_speed;
	speed = (100000/tmp);
	if (speed >= 6000)
	{
		strcpy(buf, "0:00");
	}
	else
	{
		sprintf(buf, "%01d:%02d", speed/60, speed%60);
	}


	LayerText max_speed_text = {buf, max_speed_frame, GAlignLeft, U_ASCII_ARIAL_16};
	P_Layer max_speed_layer = app_layer_create_text(&max_speed_text);
	app_window_add_layer(p_window, max_speed_layer);


	app_window_click_subscribe(p_window, ButtonIdBack, run_helper_finish_select_back);
	app_window_click_subscribe(p_window, ButtonIdSelect, run_helper_finish_select_select);

	return p_window;
}














void run_helper_timer_callback(date_time_t tick_time, uint32_t millis, void *context)
{
	static int8_t pre_min = 0;


	if (g_run.flag == 1)
	{
		g_run.sys_micro = millis - 1000;
		g_run.flag = 0;
	}
	g_run.time += (millis - g_run.sys_micro);
	g_run.sys_micro = millis;




	/*更新距离、实时配速、卡路里*/
	SportData data;
	maibu_get_sport_data(&data, 0);
	
	/*由于每天凌晨，系统会保存前一天的运动数据，并清零。所有这里需要特殊处理*/
	int16_t cur_speed = data.distance - g_run.pre_distance;
	cur_speed = cur_speed < 0 ? 0 : cur_speed;
	g_run.pre_distance = data.distance;
	int16_t cur_calorie = data.calorie - g_run.pre_calorie;
	cur_calorie = cur_calorie < 0 ? 0 : cur_calorie;
	g_run.pre_calorie = data.calorie;	

//	printf("---------:%d \n", g_run.total_calorie);


	/*第一次起步*/
	if ((g_run.total_distance == 0) && (cur_speed > 0))
	{
		g_run.curr_speed = cur_speed / (g_run.time/1000);
		g_run.pre_n_total_distance = g_run.curr_speed * RUN_HELPER_SECONDS_INTERVAL;
	}
	else 
	{
		int32_t average = g_run.pre_n_total_distance / RUN_HELPER_SECONDS_INTERVAL;
		g_run.pre_n_total_distance += cur_speed;
		g_run.pre_n_total_distance -= average;
		g_run.curr_speed = g_run.pre_n_total_distance / RUN_HELPER_SECONDS_INTERVAL;

	}
	
/*
	else
	{
		g_run.pre_n_total_distance = cur_speed * RUN_HELPER_SECONDS_INTERVAL;
		g_run.curr_speed = cur_speed;  
	}
*/
	g_run.max_speed = g_run.curr_speed > g_run.max_speed ? g_run.curr_speed : g_run.max_speed;
	g_run.total_distance += cur_speed;
	g_run.total_calorie += cur_calorie;

	 /*根据窗口ID获取窗口句柄*/
	P_Window p_window = app_window_stack_get_window_by_id(g_run_window_id);
	if (NULL == p_window)
	{
		return ;
	}

		
	/*更新时间*/
	char str[20] = "";
	char tmp[10] = "";
	struct date_time datetime;
	app_service_get_datetime(&datetime);
	if (pre_min != datetime.min)
	{
		pre_min = datetime.min;
		P_Layer p_hm_layer = app_window_get_layer_by_id(p_window, g_run_status_bar_layer_id);
		if (NULL == p_hm_layer)
		{
			return;
		}

		sprintf(str, "%02d:%02d", datetime.hour, datetime.min);
		app_layer_set_text_text(p_hm_layer, str);
	}


	/*更新距离显示*/
	P_Layer p_distance_layer = app_window_get_layer_by_id(p_window, g_run_distance_layer_id);
	if (NULL != p_distance_layer)
	{
		memset(tmp, 0, sizeof(tmp));
		maibu_layer_get_text_text(p_distance_layer, tmp, sizeof(tmp));
		sprintf(str, "%01d.%02d", g_run.total_distance/100000, ((g_run.total_distance/1000)%100));
		//sprintf(str, "%d", cur_speed);;	
		if (0  != strcmp(tmp, str))
		{
			app_layer_set_text_text(p_distance_layer, str);
		}
	}

	/*更新计时*/
	P_Layer p_time_layer = app_window_get_layer_by_id(p_window, g_run_time_layer_id);
	if (NULL != p_time_layer)
	{
		memset(tmp, 0, sizeof(tmp));
		maibu_layer_get_text_text(p_time_layer, tmp, sizeof(tmp));
		if ((g_run.time/1000) >= 3600)
		{
			sprintf(str, "%01d:%02d",  g_run.time/3600000, (g_run.time/60000)%60);
		}
		else
		{
			sprintf(str, "%01d:%02d",  g_run.time/60000, (g_run.time/1000)%60);
		}
		if (0  != strcmp(tmp, str))
		{
			app_layer_set_text_text(p_time_layer, str);
		}
	}
	
	/*更新配速显示*/
	P_Layer p_speed_layer = app_window_get_layer_by_id(p_window, g_run_speed_layer_id);
	if (NULL != p_speed_layer)
	{
		memset(tmp, 0, sizeof(tmp));
		maibu_layer_get_text_text(p_speed_layer, tmp, sizeof(tmp));
//		int32_t hour_speed = g_run.curr_speed * 60;
	
		int32_t hour_speed = g_run.curr_speed == 0 ? 1 : g_run.curr_speed;	
		hour_speed = (100000/hour_speed);
		if (hour_speed >= 6000)
		{
			strcpy(str, "0:00");
		}
		else
		{
			sprintf(str, "%01d:%02d", hour_speed/60, hour_speed%60);
		}
		if (0  != strcmp(tmp, str))
		{
			app_layer_set_text_text(p_speed_layer, str);
		}
	}
	
	
	app_window_update(p_window);

}




/*
 *--------------------------------------------------------------------------------------
 *     function:  run_helper_create_init_window
 *    parameter: 
 *       return:
 *  description:  创建初始化窗口
 * 	  other:
 *--------------------------------------------------------------------------------------
 */
P_Window run_helper_create_init_window()
{
	P_Window p_window = NULL;

	/*根据不同状态显示不同窗口*/
	if(g_run.state == RUN_HELPER_STATE_INTRO)
	{
		p_window = run_helper_create_intro_window();	
	}
	else if(g_run.state == RUN_HELPER_STATE_FINISH)
	{
		p_window = run_helper_create_finish_window();	
	}
	else
	{
		p_window = run_helper_create_record_window();	
	}

	return p_window;
}



int main()
{

	
#ifdef LINUX	
	/*非APP编写*/	
	screen_init(SCREEN_ROW_NUMS,SCREEN_COL_NUMS);
	os_store_manage_init();	
	window_stack_init();
	os_comm_init();
	set_current_app(0x7d701);
//	g_run.cur_micro = (600000 - 100);
//	g_run.record[0] = 600000 - 500;
//	g_run.record_index = 1;
#endif


	P_Window p_window = run_helper_create_init_window(); 

	/*放入窗口栈显示*/
	g_run_window_id = app_window_stack_push(p_window);





#ifdef LINUX
	/*非APP编写*/	
	SHOW;
	while (1)
	{
		char input;	
	
		/*输入操作*/
		scanf("%c", &input);
		if (input == 'd')
		{
			window_stack_button(ButtonIdDown);	
		}
		else if (input == 'u')
		{
			window_stack_button(ButtonIdUp);	
		}	
		else if (input == 's')
		{
			window_stack_button(ButtonIdSelect);		
		}
		else if (input == 'b')
		{
			window_stack_button(ButtonIdBack);		
		}
		else if (input == 'q')
		{
			break;
		}
	
	}	
	SHOW;

	window_stack_destory();
	screen_destory();
	os_store_manage_destory();

	SHOW;
#endif
	return 0;

}

